# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Inventory Service."""

__version__ = "0.2.15"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .apimodels_admin_update_item_req import ApimodelsAdminUpdateItemReq
from .apimodels_bulk_save_item_error import ApimodelsBulkSaveItemError
from .apimodels_bulk_save_item_resp import ApimodelsBulkSaveItemResp
from .apimodels_chaining_operation_req import ApimodelsChainingOperationReq
from .apimodels_chaining_operation_resp import ApimodelsChainingOperationResp
from .apimodels_consume_item import ApimodelsConsumeItem
from .apimodels_consume_item_req import ApimodelsConsumeItemReq
from .apimodels_create_integration_configuration_req import (
    ApimodelsCreateIntegrationConfigurationReq,
)
from .apimodels_create_inventory_configuration_req import (
    ApimodelsCreateInventoryConfigurationReq,
)
from .apimodels_create_inventory_req import ApimodelsCreateInventoryReq
from .apimodels_create_item import ApimodelsCreateItem
from .apimodels_create_item import SourceEnum as ApimodelsCreateItemSourceEnum
from .apimodels_create_item_type_req import ApimodelsCreateItemTypeReq
from .apimodels_create_item_type_resp import ApimodelsCreateItemTypeResp
from .apimodels_create_tag_req import ApimodelsCreateTagReq
from .apimodels_create_tag_req import OwnerEnum as ApimodelsCreateTagReqOwnerEnum
from .apimodels_create_tag_resp import ApimodelsCreateTagResp
from .apimodels_create_tag_resp import OwnerEnum as ApimodelsCreateTagRespOwnerEnum
from .apimodels_delete_inventory_req import ApimodelsDeleteInventoryReq
from .apimodels_error_response import ApimodelsErrorResponse
from .apimodels_integration_configuration_resp import (
    ApimodelsIntegrationConfigurationResp,
)
from .apimodels_inventory_config import ApimodelsInventoryConfig
from .apimodels_inventory_configuration_req import ApimodelsInventoryConfigurationReq
from .apimodels_inventory_configuration_resp import ApimodelsInventoryConfigurationResp
from .apimodels_inventory_configuration_resp import (
    StatusEnum as ApimodelsInventoryConfigurationRespStatusEnum,
)
from .apimodels_inventory_resp import ApimodelsInventoryResp
from .apimodels_item_resp import ApimodelsItemResp
from .apimodels_list_integration_configurations_resp import (
    ApimodelsListIntegrationConfigurationsResp,
)
from .apimodels_list_inventory_configurations_resp import (
    ApimodelsListInventoryConfigurationsResp,
)
from .apimodels_list_inventory_resp import ApimodelsListInventoryResp
from .apimodels_list_item_resp import ApimodelsListItemResp
from .apimodels_list_item_types_resp import ApimodelsListItemTypesResp
from .apimodels_list_tags_resp import ApimodelsListTagsResp
from .apimodels_move_items_req import ApimodelsMoveItemsReq
from .apimodels_move_items_resp import ApimodelsMoveItemsResp
from .apimodels_operation import ApimodelsOperation
from .apimodels_paging import ApimodelsPaging
from .apimodels_purchase_validation_item_req import ApimodelsPurchaseValidationItemReq
from .apimodels_purchase_validation_req import ApimodelsPurchaseValidationReq
from .apimodels_remove_inventory_item_req import ApimodelsRemoveInventoryItemReq
from .apimodels_remove_item import ApimodelsRemoveItem
from .apimodels_save_item_req import ApimodelsSaveItemReq
from .apimodels_save_item_req import SourceEnum as ApimodelsSaveItemReqSourceEnum
from .apimodels_save_item_to_inventory_req import ApimodelsSaveItemToInventoryReq
from .apimodels_save_item_to_inventory_req import (
    SourceEnum as ApimodelsSaveItemToInventoryReqSourceEnum,
)
from .apimodels_trade_item import ApimodelsTradeItem
from .apimodels_trade_item_resp import ApimodelsTradeItemResp
from .apimodels_update_integration_configuration_req import (
    ApimodelsUpdateIntegrationConfigurationReq,
)
from .apimodels_update_inventory_req import ApimodelsUpdateInventoryReq
from .apimodels_update_item import ApimodelsUpdateItem
from .apimodels_update_item_req import ApimodelsUpdateItemReq
from .apimodels_update_item_resp import ApimodelsUpdateItemResp
from .apimodels_update_status_integration_configuration_req import (
    ApimodelsUpdateStatusIntegrationConfigurationReq,
)
from .apimodels_update_status_integration_configuration_req import (
    StatusEnum as ApimodelsUpdateStatusIntegrationConfigurationReqStatusEnum,
)
